TextLayerData class

Attributes used by TextLayer

Inheritance

Constructors

TextLayerData({required String text, double size = 64, Color color = Colors.white, Color background = Colors.transparent, double backgroundOpacity = 0, TextAlign align = TextAlign.left, Offset offset = const Offset(64, 64), double opacity = 1, double rotation = 0, double scale = 1})

Properties

align ↔ TextAlign
getter/setter pair
background ↔ Color
getter/setter pair
backgroundOpacity ↔ double
getter/setter pair
color ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offset ↔ Offset
getter/setter pairinherited
opacity ↔ double
getter/setter pairinherited
rotation ↔ double
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ double
getter/setter pairinherited
size ↔ double
getter/setter pair
text ↔ String
getter/setter pair

Methods

copyFrom(Map json) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map json) → TextLayerData
override