LoadingScreen class

Constructors

LoadingScreen({Color? color, required GlobalKey<NavigatorState> globalKey})

Properties

color → Color?
final
globalKey → GlobalKey<NavigatorState>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show({String? text}) → LoadingScreenHandler
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited