ImagePickerOption class

Constructors

ImagePickerOption({bool pickFromGallery = false, bool captureFromCamera = false, int maxLength = 99})
const

Properties

captureFromCamera → bool
final
hashCode → int
The hash code for this object.
no setterinherited
maxLength → int
final
pickFromGallery → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited